;;; theme-loaddefs.el --- automatically extracted autoloads (do not edit)   -*- lexical-binding: t -*-
;; Generated by the `loaddefs-generate' function.

;; This file is part of GNU Emacs.

;;; Code:



;;; Generated autoloads from ../etc/themes/adwaita-theme.el

(put 'adwaita 'theme-properties (list :background-mode 'light :kind 'color-scheme))
(register-definition-prefixes "etc/themes/adwaita-theme" '("adwaita"))


;;; Generated autoloads from ../etc/themes/deeper-blue-theme.el

(put 'deeper-blue 'theme-properties (list :background-mode 'dark :kind 'color-scheme))
(register-definition-prefixes "etc/themes/deeper-blue-theme" '("deeper-blue"))


;;; Generated autoloads from ../etc/themes/dichromacy-theme.el

(put 'dichromacy 'theme-properties (list :background-mode 'light :kind 'color-scheme))
(register-definition-prefixes "etc/themes/dichromacy-theme" '("dichromacy"))


;;; Generated autoloads from ../etc/themes/leuven-dark-theme.el

(put 'leuven-dark 'theme-properties (list :background-mode 'dark :family 'leuven :kind 'color-scheme))
(register-definition-prefixes "etc/themes/leuven-dark-theme" '("leuven-dark"))


;;; Generated autoloads from ../etc/themes/leuven-theme.el

(put 'leuven 'theme-properties (list :background-mode 'light :kind 'color-scheme :family 'leuven))
(register-definition-prefixes "etc/themes/leuven-theme" '("leuven"))


;;; Generated autoloads from ../etc/themes/light-blue-theme.el

(put 'light-blue 'theme-properties (list :background-mode 'light :kind 'color-scheme))
(register-definition-prefixes "etc/themes/light-blue-theme" '("light-blue"))


;;; Generated autoloads from ../etc/themes/manoj-dark-theme.el

(put 'manoj-dark 'theme-properties (list :background-mode 'dark :kind 'color-scheme))
(register-definition-prefixes "etc/themes/manoj-dark-theme" '("manoj-dark"))


;;; Generated autoloads from ../etc/themes/misterioso-theme.el

(put 'misterioso 'theme-properties (list :background-mode 'dark :kind 'color-scheme))
(register-definition-prefixes "etc/themes/misterioso-theme" '("misterioso"))


;;; Generated autoloads from ../etc/themes/modus-operandi-deuteranopia-theme.el

(put 'modus-operandi-deuteranopia 'theme-properties (list :background-mode 'light :kind 'color-scheme :family 'modus))


;;; Generated autoloads from ../etc/themes/modus-operandi-theme.el

(put 'modus-operandi 'theme-properties (list :background-mode 'light :kind 'color-scheme :family 'modus))


;;; Generated autoloads from ../etc/themes/modus-operandi-tinted-theme.el

(put 'modus-operandi-tinted 'theme-properties (list :background-mode 'light :kind 'color-scheme :family 'modus))


;;; Generated autoloads from ../etc/themes/modus-operandi-tritanopia-theme.el

(put 'modus-operandi-tritanopia 'theme-properties (list :background-mode 'light :kind 'color-scheme :family 'modus))


;;; Generated autoloads from ../etc/themes/modus-themes.el

(register-definition-prefixes "etc/themes/modus-themes" '("modus-themes-"))


;;; Generated autoloads from ../etc/themes/modus-vivendi-deuteranopia-theme.el

(put 'modus-vivendi-deuteranopia 'theme-properties (list :background-mode 'dark :kind 'color-scheme :family 'modus))


;;; Generated autoloads from ../etc/themes/modus-vivendi-theme.el

(put 'modus-vivendi 'theme-properties (list :background-mode 'dark :kind 'color-scheme :family 'modus))


;;; Generated autoloads from ../etc/themes/modus-vivendi-tinted-theme.el

(put 'modus-vivendi-tinted 'theme-properties (list :background-mode 'dark :kind 'color-scheme :family 'modus))


;;; Generated autoloads from ../etc/themes/modus-vivendi-tritanopia-theme.el

(put 'modus-vivendi-tritanopia 'theme-properties (list :background-mode 'dark :kind 'color-scheme :family 'modus))


;;; Generated autoloads from ../etc/themes/tango-dark-theme.el

(put 'tango-dark 'theme-properties (list :background-mode 'dark :kind 'color-scheme :family 'tango))
(register-definition-prefixes "etc/themes/tango-dark-theme" '("tango-dark"))


;;; Generated autoloads from ../etc/themes/tango-theme.el

(put 'tango 'theme-properties (list :background-mode 'light :kind 'color-scheme :family 'tango))
(register-definition-prefixes "etc/themes/tango-theme" '("tango"))


;;; Generated autoloads from ../etc/themes/tsdh-dark-theme.el

(put 'tsdh-dark 'theme-properties (list :background-mode 'dark :kind 'color-scheme :family 'tsdh))
(register-definition-prefixes "etc/themes/tsdh-dark-theme" '("tsdh-dark"))


;;; Generated autoloads from ../etc/themes/tsdh-light-theme.el

(put 'tsdh-light 'theme-properties (list :background-mode 'light :kind 'color-scheme :family 'tsdh))
(register-definition-prefixes "etc/themes/tsdh-light-theme" '("tsdh-light"))


;;; Generated autoloads from ../etc/themes/wheatgrass-theme.el

(put 'wheatgrass 'theme-properties (list :background-mode 'dark :kind 'color-scheme))
(register-definition-prefixes "etc/themes/wheatgrass-theme" '("wheatgrass"))


;;; Generated autoloads from ../etc/themes/whiteboard-theme.el

(put 'whiteboard 'theme-properties (list :background-mode 'light :kind 'color-scheme))
(register-definition-prefixes "etc/themes/whiteboard-theme" '("whiteboard"))


;;; Generated autoloads from ../etc/themes/wombat-theme.el

(put 'wombat 'theme-properties (list :background-mode 'dark :kind 'color-scheme))
(register-definition-prefixes "etc/themes/wombat-theme" '("wombat"))

;;; End of scraped data

(provide 'theme-loaddefs)

;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; no-native-compile: t
;; coding: utf-8-emacs-unix
;; End:

;;; theme-loaddefs.el ends here
